![](https://raw.githubusercontent.com/rzel/twpy/main/twpy_app_icon_1_vecta_compressed.svg)

**twpy** was designed to be the *best* desktop GUI client for editing and managing **TiddlyWiki** files - simple, powerful, elegant, efficient.

Installation is as simple as: 

`pip install tiddlywiki`

Two terminal commands are installed:

**twpym** for starting the **twpy** TiddlyWiki Manager. **--verbose** is an option. You can open TiddlyWiki files in the Editor from the Manager.

**twpye** for starting the **twpy** TiddlyWiki Editor. Requires **--file your-tiddly-wiki-path.html** argument. **--verbose** is also an option. 


**TiddlyWiki Manager**

![](https://raw.githubusercontent.com/rzel/twpy/main/twpy-screenshot-2022-10-17--22-49-32.png)

**TiddlyWiki Editor**

![](https://raw.githubusercontent.com/rzel/twpy/main/twpy-screenshot-2022-10-17--22-50-38.png)
